Experiment Comparison

# PromptLab

Select columns to display ▼

| Experiment ID | Model Type | Embedding Model | Inference Model | Prompt Template ID | Prompt Template Version | Dataset ID | Dataset Version | System Prompt | User Prompt
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---

Experiment ID | Dataset Record ID | Inference | Completion Tokens | Prompt Tokens | Latency (ms) | ragas-SemanticSimilarity | ragas-RougeScore
--- | --- | --- | --- | --- | --- | --- | ---

# Prompt Templates

Id | Name | Description | Version | Created At | System Prompt | User Prompt | Deployment Time | Is Deployed
--- | --- | --- | --- | --- | --- | --- | --- | ---

# Assets

Asset management content will go here.

# Datasets

Id | Name | Description | Version | Created At | File Path
--- | --- | --- | --- | --- | ---